@@ -19,10 +19,11 @@
 
 import unittest
 from datetime import date
-
-from unittest.mock import patch
 from pathlib import Path
+from unittest.mock import patch
+
 from lxml import etree
+
 from . import GmpMockFactory, load_script
 
 CWD = Path(__file__).absolute().parent
@@ -31,7 +32,7 @@ CWD = Path(__file__).absolute().parent
 class CreateConsolidatedReportsTestCase(unittest.TestCase):
     def setUp(self):
         self.create_consolidated_report = load_script(
-            (CWD.parent.parent / 'scripts'), 'create-consolidated-report'
+            (CWD.parent.parent / "scripts"), "create-consolidated-report"
         )
 
     def test_parse_period(self):
@@ -82,7 +83,7 @@ class CreateConsolidatedReportsTestCase(unittest.TestCase):
         self.assertEqual(date2, date(2001, 2, 3))
 
     def test_parse_tags(self):
-        tags = ['abc', 'dba8624e-a56c-4901-a3f2-591f062e4c20']
+        tags = ["abc", "dba8624e-a56c-4901-a3f2-591f062e4c20"]
 
         filter_tags = self.create_consolidated_report.parse_tags(tags)
 
@@ -93,7 +94,7 @@ class CreateConsolidatedReportsTestCase(unittest.TestCase):
 
     def test_generate_task_filter(self):
         asserted_task_filter = (
-            'rows=-1 last>2020-01-01 and last<2020-02-01 and tag="blah"'
+            'rows=-1 last>2020-01-01 and created<2020-02-01 and tag="blah"'
         )
         period_start = date(2020, 1, 1)
         period_end = date(2020, 2, 1)
@@ -106,8 +107,8 @@ class CreateConsolidatedReportsTestCase(unittest.TestCase):
         self.assertEqual(task_filter, asserted_task_filter)
 
         asserted_task_filter = (
-            'rows=-1 last>2020-01-01 and last<2020-02-01 and '
-            'tag="blah" or last>2020-01-01 and last<2020-02-01'
+            "rows=-1 last>2020-01-01 and created<2020-02-01 and "
+            'tag="blah" or last>2020-01-01 and created<2020-02-01'
             ' and tag="blah2"'
         )
         tags = ['tag="blah"', 'tag="blah2"']
@@ -118,126 +119,79 @@ class CreateConsolidatedReportsTestCase(unittest.TestCase):
 
         self.assertEqual(task_filter, asserted_task_filter)
 
-    @patch('gvm.protocols.latest.Gmp', new_callable=GmpMockFactory)
-    def test_get_last_reports_from_tasks(self, mock_gmp: GmpMockFactory):
-        mock_gmp.mock_response(
-            'get_tasks',
-            '<get_tasks_response status="200" status_text="OK">'
-            '  <apply_overrides>0</apply_overrides>'
-            '  <task id="ef4469db-1cd7-4859-ba5f-45f72f49f09e">'
-            '    <last_report>'
-            '      <report id="4108fe11-91c8-4b7b-90da-854e3200af19">'
-            '      </report>'
-            '    </last_report>'
-            '  </task>'
-            '  <task id="bdd80dd6-9c7b-47b9-a87b-e2ca28fae2df">'
-            '    <last_report>'
-            '      <report id="55af942a-fa45-472c-aa50-f2af77d700a0">'
-            '      </report>'
-            '    </last_report>'
-            '  </task>'
-            '  <task id="6e5373cd-e69a-4008-afc3-a6d05e22507f">'
-            '    <last_report>'
-            '      <report id="52b67045-2c2c-4dbd-af58-ecf814d92f07">'
-            '      </report>'
-            '    </last_report>'
-            '  </task>'
-            '  <task id="bab515c2-156b-451f-9f1c-7af5b2c4b568">'
-            '    <last_report>'
-            '      <report id="52b67045-2c2c-4dbd-af58-ecf814d92f07">'
-            '      </report>'
-            '    </last_report>'
-            '  </task>'
-            '</get_tasks_response>',
-        )
-
-        reports = self.create_consolidated_report.get_last_reports_from_tasks(
-            mock_gmp.gmp_protocol,
-            task_filter=(
-                'rows=-1 last>2020-01-01 and ' 'last<2020-02-01 and tag="blah"'
-            ),
-        )
-
-        asserted_reports = [
-            '4108fe11-91c8-4b7b-90da-854e3200af19',
-            '55af942a-fa45-472c-aa50-f2af77d700a0',
-            '52b67045-2c2c-4dbd-af58-ecf814d92f07',
-        ]
-        self.assertEqual(reports, asserted_reports)
-
-    @patch('gvm.protocols.latest.Gmp', new_callable=GmpMockFactory)
+    @patch("gvm.protocols.latest.Gmp", new_callable=GmpMockFactory)
     def test_combine_reports_with_term(self, mock_gmp: GmpMockFactory):
         reports = [
-            '00000000-0000-0000-0000-000000000000',
-            '00000000-0000-0000-0000-000000000001',
-            '00000000-0000-0000-0000-000000000002',
+            "00000000-0000-0000-0000-000000000000",
+            "00000000-0000-0000-0000-000000000001",
+            "00000000-0000-0000-0000-000000000002",
         ]
 
         mock_gmp.mock_responses(
-            'get_report',
+            "get_report",
             [
                 '<get_reports_response status="200" status_text="OK">'
                 '<report id="00000000-0000-0000-0000-000000000000">'
-                '<name>2020-11-13T14:47:28Z</name>'
-                '<creation_time>2020-11-13T14:47:28Z</creation_time>'
-                '<modification_time>2020-11-13T14:47:28Z</modification_time>'
+                "<name>2020-11-13T14:47:28Z</name>"
+                "<creation_time>2020-11-13T14:47:28Z</creation_time>"
+                "<modification_time>2020-11-13T14:47:28Z</modification_time>"
                 '<task id="00000000-0000-0000-0001-000000000000">'
-                '<name>Offline Scan from 2020-11-13T15:47:28+01:00 8</name>'
-                '</task>'
+                "<name>Offline Scan from 2020-11-13T15:47:28+01:00 8</name>"
+                "</task>"
                 '<report id="00000000-0000-0000-0000-000000000000">'
-                '<scan_run_status>Done</scan_run_status>'
-                '<timestamp>2020-11-13T14:47:48Z</timestamp>'
-                '<scan_start>2020-11-13T14:47:28Z</scan_start>'
+                "<scan_run_status>Done</scan_run_status>"
+                "<timestamp>2020-11-13T14:47:48Z</timestamp>"
+                "<scan_start>2020-11-13T14:47:28Z</scan_start>"
                 '<ports max="-1" start="1">'
-                '<port>0<host>127.0.0.0</host></port>'
-                '<port>1<host>127.0.0.1</host></port></ports>'
+                "<port>0<host>127.0.0.0</host></port>"
+                "<port>1<host>127.0.0.1</host></port></ports>"
                 '<results start="1" max="100">'
                 '<result id="00000001-0000-0000-0000-000000000000">'
-                '</result>'
+                "</result>"
                 '<result id="00000001-0000-0000-0000-000000000001">'
-                '</result></results>'
-                '<scan_end>2020-11-13T14:47:28Z</scan_end>'
-                '</report></report></get_reports_response>',
+                "</result></results>"
+                "<scan_end>2020-11-13T14:47:28Z</scan_end>"
+                "</report></report></get_reports_response>",
                 '<get_reports_response status="200" status_text="OK">'
                 '<report id="00000000-0000-0000-0000-000000000001">'
-                '<name>2020-11-13T14:47:28Z</name>'
-                '<creation_time>2020-11-13T14:47:28Z</creation_time>'
-                '<modification_time>2020-11-13T14:47:28Z</modification_time>'
+                "<name>2020-11-13T14:47:28Z</name>"
+                "<creation_time>2020-11-13T14:47:28Z</creation_time>"
+                "<modification_time>2020-11-13T14:47:28Z</modification_time>"
                 '<task id="00000000-0000-0000-0002-000000000000">'
-                '<name>Offline Scan from 2020-11-13T15:47:28+01:00 8</name>'
-                '</task>'
+                "<name>Offline Scan from 2020-11-13T15:47:28+01:00 8</name>"
+                "</task>"
                 '<report id="00000000-0000-0000-0000-000000000001">'
-                '<scan_run_status>Done</scan_run_status>'
-                '<timestamp>2020-11-13T14:47:48Z</timestamp>'
-                '<scan_start>2020-11-13T14:47:28Z</scan_start>'
+                "<scan_run_status>Done</scan_run_status>"
+                "<timestamp>2020-11-13T14:47:48Z</timestamp>"
+                "<scan_start>2020-11-13T14:47:28Z</scan_start>"
                 '<ports max="-1" start="1">'
-                '<port>2<host>127.0.0.2</host></port>'
-                '<port>3<host>127.0.0.3</host></port></ports>'
+                "<port>2<host>127.0.0.2</host></port>"
+                "<port>3<host>127.0.0.3</host></port></ports>"
                 '<results start="1" max="100">'
                 '<result id="00000001-0000-0000-0000-000000000002"></result>'
                 '<result id="00000001-0000-0000-0000-000000000003">'
-                '</result></results>'
-                '<scan_end>2020-11-13T14:47:28Z</scan_end>'
-                '<host><ip>127.0.0.0</ip></host></report>'
-                '</report></get_reports_response>',
+                "</result></results>"
+                "<scan_end>2020-11-13T14:47:28Z</scan_end>"
+                "<host><ip>127.0.0.0</ip></host></report>"
+                "</report></get_reports_response>",
                 '<get_reports_response status="200" status_text="OK">'
                 '<report id="00000000-0000-0000-0000-000000000002">'
-                '<name>2020-11-13T14:47:28Z</name>'
-                '<creation_time>2020-11-13T14:47:28Z</creation_time>'
-                '<modification_time>2020-11-13T14:47:28Z</modification_time>'
+                "<name>2020-11-13T14:47:28Z</name>"
+                "<creation_time>2020-11-13T14:47:28Z</creation_time>"
+                "<modification_time>2020-11-13T14:47:28Z</modification_time>"
                 '<task id="00000000-0000-0000-0003-000000000000">'
-                '<name>Offline Scan from 2020-11-13T15:47:28+01:00 8</name>'
-                '</task>'
+                "<name>Offline Scan from 2020-11-13T15:47:28+01:00 8</name>"
+                "</task>"
                 '<report id="00000000-0000-0000-0000-000000000002">'
-                '<scan_run_status>Done</scan_run_status>'
-                '<timestamp>2020-11-13T14:47:48Z</timestamp>'
-                '<scan_start>2020-11-13T14:47:28Z</scan_start>'
+                "<scan_run_status>Done</scan_run_status>"
+                "<timestamp>2020-11-13T14:47:48Z</timestamp>"
+                "<scan_start>2020-11-13T14:47:28Z</scan_start>"
                 '<results start="1" max="100">'
                 '<result id="00000001-0000-0000-0000-000000000004">'
-                '</result></results>'
-                '<scan_end>2020-11-13T14:47:28Z</scan_end>'
-                '<host><ip>127.0.0.1</ip></host></report>'
-                '</report></get_reports_response>',
+                "</result></results>"
+                "<scan_end>2020-11-13T14:47:28Z</scan_end>"
+                "<host><ip>127.0.0.1</ip></host></report>"
+                "</report></get_reports_response>",
             ],
         )
 
@@ -245,145 +199,145 @@ class CreateConsolidatedReportsTestCase(unittest.TestCase):
             mock_gmp.gmp_protocol, reports, filter_term="foo", filter_id=None
         )
 
-        ports = combined_report.find('report').find('ports').findall('port')
+        ports = combined_report.find("report").find("ports").findall("port")
         i = 0
         for port in ports:
-            self.assertEqual(port.text, f'{str(i)}')
+            self.assertEqual(port.text, f"{str(i)}")
             i += 1
 
         self.assertEqual(i, 4)
 
         results = (
-            combined_report.find('report').find('results').findall('result')
+            combined_report.find("report").find("results").findall("result")
         )
         i = 0
         for result in results:
             self.assertEqual(
-                result.get('id'), f'00000001-0000-0000-0000-00000000000{str(i)}'
+                result.get("id"), f"00000001-0000-0000-0000-00000000000{str(i)}"
             )
             i += 1
 
         self.assertEqual(i, 5)
 
-        hosts = combined_report.find('report').findall('host')
+        hosts = combined_report.find("report").findall("host")
 
         i = 0
         for host in hosts:
-            self.assertEqual(host.find('ip').text, f'127.0.0.{str(i)}')
+            self.assertEqual(host.find("ip").text, f"127.0.0.{str(i)}")
             i += 1
 
         self.assertEqual(i, 2)
 
-    @patch('gvm.protocols.latest.Gmp', new_callable=GmpMockFactory)
+    @patch("gvm.protocols.latest.Gmp", new_callable=GmpMockFactory)
     def test_combine_reports_with_id(self, mock_gmp: GmpMockFactory):
         reports = [
-            '00000000-0000-0000-0000-000000000000',
-            '00000000-0000-0000-0000-000000000001',
-            '00000000-0000-0000-0000-000000000002',
+            "00000000-0000-0000-0000-000000000000",
+            "00000000-0000-0000-0000-000000000001",
+            "00000000-0000-0000-0000-000000000002",
         ]
 
         mock_gmp.mock_responses(
-            'get_report',
+            "get_report",
             [
                 '<get_reports_response status="200" status_text="OK">'
                 '<report id="00000000-0000-0000-0000-000000000000">'
-                '<name>2020-11-13T14:47:28Z</name>'
-                '<creation_time>2020-11-13T14:47:28Z</creation_time>'
-                '<modification_time>2020-11-13T14:47:28Z</modification_time>'
+                "<name>2020-11-13T14:47:28Z</name>"
+                "<creation_time>2020-11-13T14:47:28Z</creation_time>"
+                "<modification_time>2020-11-13T14:47:28Z</modification_time>"
                 '<task id="00000000-0000-0000-0001-000000000000">'
-                '<name>Offline Scan from 2020-11-13T15:47:28+01:00 8</name>'
-                '</task>'
+                "<name>Offline Scan from 2020-11-13T15:47:28+01:00 8</name>"
+                "</task>"
                 '<report id="00000000-0000-0000-0000-000000000000">'
-                '<scan_run_status>Done</scan_run_status>'
-                '<timestamp>2020-11-13T14:47:48Z</timestamp>'
-                '<scan_start>2020-11-13T14:47:28Z</scan_start>'
+                "<scan_run_status>Done</scan_run_status>"
+                "<timestamp>2020-11-13T14:47:48Z</timestamp>"
+                "<scan_start>2020-11-13T14:47:28Z</scan_start>"
                 '<ports max="-1" start="1">'
-                '<port>0<host>127.0.0.0</host></port>'
-                '<port>1<host>127.0.0.1</host></port></ports>'
+                "<port>0<host>127.0.0.0</host></port>"
+                "<port>1<host>127.0.0.1</host></port></ports>"
                 '<results start="1" max="100">'
                 '<result id="00000001-0000-0000-0000-000000000000">'
-                '</result>'
+                "</result>"
                 '<result id="00000001-0000-0000-0000-000000000001">'
-                '</result></results>'
-                '<scan_end>2020-11-13T14:47:28Z</scan_end>'
-                '</report></report></get_reports_response>',
+                "</result></results>"
+                "<scan_end>2020-11-13T14:47:28Z</scan_end>"
+                "</report></report></get_reports_response>",
                 '<get_reports_response status="200" status_text="OK">'
                 '<report id="00000000-0000-0000-0000-000000000001">'
-                '<name>2020-11-13T14:47:28Z</name>'
-                '<creation_time>2020-11-13T14:47:28Z</creation_time>'
-                '<modification_time>2020-11-13T14:47:28Z</modification_time>'
+                "<name>2020-11-13T14:47:28Z</name>"
+                "<creation_time>2020-11-13T14:47:28Z</creation_time>"
+                "<modification_time>2020-11-13T14:47:28Z</modification_time>"
                 '<task id="00000000-0000-0000-0002-000000000000">'
-                '<name>Offline Scan from 2020-11-13T15:47:28+01:00 8</name>'
-                '</task>'
+                "<name>Offline Scan from 2020-11-13T15:47:28+01:00 8</name>"
+                "</task>"
                 '<report id="00000000-0000-0000-0000-000000000001">'
-                '<scan_run_status>Done</scan_run_status>'
-                '<timestamp>2020-11-13T14:47:48Z</timestamp>'
-                '<scan_start>2020-11-13T14:47:28Z</scan_start>'
+                "<scan_run_status>Done</scan_run_status>"
+                "<timestamp>2020-11-13T14:47:48Z</timestamp>"
+                "<scan_start>2020-11-13T14:47:28Z</scan_start>"
                 '<ports max="-1" start="1">'
-                '<port>2<host>127.0.0.2</host></port>'
-                '<port>3<host>127.0.0.3</host></port></ports>'
+                "<port>2<host>127.0.0.2</host></port>"
+                "<port>3<host>127.0.0.3</host></port></ports>"
                 '<results start="1" max="100">'
                 '<result id="00000001-0000-0000-0000-000000000002"></result>'
                 '<result id="00000001-0000-0000-0000-000000000003">'
-                '</result></results>'
-                '<scan_end>2020-11-13T14:47:28Z</scan_end>'
-                '<host><ip>127.0.0.0</ip></host></report>'
-                '</report></get_reports_response>',
+                "</result></results>"
+                "<scan_end>2020-11-13T14:47:28Z</scan_end>"
+                "<host><ip>127.0.0.0</ip></host></report>"
+                "</report></get_reports_response>",
                 '<get_reports_response status="200" status_text="OK">'
                 '<report id="00000000-0000-0000-0000-000000000002">'
-                '<name>2020-11-13T14:47:28Z</name>'
-                '<creation_time>2020-11-13T14:47:28Z</creation_time>'
-                '<modification_time>2020-11-13T14:47:28Z</modification_time>'
+                "<name>2020-11-13T14:47:28Z</name>"
+                "<creation_time>2020-11-13T14:47:28Z</creation_time>"
+                "<modification_time>2020-11-13T14:47:28Z</modification_time>"
                 '<task id="00000000-0000-0000-0003-000000000000">'
-                '<name>Offline Scan from 2020-11-13T15:47:28+01:00 8</name>'
-                '</task>'
+                "<name>Offline Scan from 2020-11-13T15:47:28+01:00 8</name>"
+                "</task>"
                 '<report id="00000000-0000-0000-0000-000000000002">'
-                '<scan_run_status>Done</scan_run_status>'
-                '<timestamp>2020-11-13T14:47:48Z</timestamp>'
-                '<scan_start>2020-11-13T14:47:28Z</scan_start>'
+                "<scan_run_status>Done</scan_run_status>"
+                "<timestamp>2020-11-13T14:47:48Z</timestamp>"
+                "<scan_start>2020-11-13T14:47:28Z</scan_start>"
                 '<results start="1" max="100">'
                 '<result id="00000001-0000-0000-0000-000000000004">'
-                '</result></results>'
-                '<scan_end>2020-11-13T14:47:28Z</scan_end>'
-                '<host><ip>127.0.0.1</ip></host></report>'
-                '</report></get_reports_response>',
+                "</result></results>"
+                "<scan_end>2020-11-13T14:47:28Z</scan_end>"
+                "<host><ip>127.0.0.1</ip></host></report>"
+                "</report></get_reports_response>",
             ],
         )
 
         combined_report = self.create_consolidated_report.combine_reports(
-            mock_gmp.gmp_protocol, reports, filter_term="", filter_id='123'
+            mock_gmp.gmp_protocol, reports, filter_term="", filter_id="123"
         )
 
-        ports = combined_report.find('report').find('ports').findall('port')
+        ports = combined_report.find("report").find("ports").findall("port")
         i = 0
         for port in ports:
-            self.assertEqual(port.text, f'{str(i)}')
+            self.assertEqual(port.text, f"{str(i)}")
             i += 1
 
         self.assertEqual(i, 4)
 
         results = (
-            combined_report.find('report').find('results').findall('result')
+            combined_report.find("report").find("results").findall("result")
         )
         i = 0
         for result in results:
             self.assertEqual(
-                result.get('id'), f'00000001-0000-0000-0000-00000000000{str(i)}'
+                result.get("id"), f"00000001-0000-0000-0000-00000000000{str(i)}"
             )
             i += 1
 
         self.assertEqual(i, 5)
 
-        hosts = combined_report.find('report').findall('host')
+        hosts = combined_report.find("report").findall("host")
 
         i = 0
         for host in hosts:
-            self.assertEqual(host.find('ip').text, f'127.0.0.{str(i)}')
+            self.assertEqual(host.find("ip").text, f"127.0.0.{str(i)}")
             i += 1
 
         self.assertEqual(i, 2)
 
-    @patch('gvm.protocols.latest.Gmp', new_callable=GmpMockFactory)
+    @patch("gvm.protocols.latest.Gmp", new_callable=GmpMockFactory)
     def test_send_report(self, mock_gmp: GmpMockFactory):
 
         combined_report = etree.fromstring(
@@ -397,19 +351,19 @@ class CreateConsolidatedReportsTestCase(unittest.TestCase):
             '<result id="00000001-0000-0000-0000-000000000002"/>'
             '<result id="00000001-0000-0000-0000-000000000003"/>'
             '<result id="00000001-0000-0000-0000-000000000004"/>'
-            '</results></report></report>'
+            "</results></report></report>"
         )
 
-        report_id = '0e4d8fb2-47fa-494e-a242-d5327d3772f9'
+        report_id = "0e4d8fb2-47fa-494e-a242-d5327d3772f9"
 
         mock_gmp.mock_response(
-            'import_report',
+            "import_report",
             '<create_report_response status="201" status_text="OK, '
             f'resource created" id="{report_id}"/>',
         )
 
         mock_gmp.mock_response(
-            'create_container_task',
+            "create_container_task",
             '<create_task_response status="201" status_text="OK, '
             'resource created" id="6488ef71-e2d5-491f-95bd-ed9f915fa179"/>',
         )
